<div align="center">
  <img src="https://github.com/lucianolorenti/ceruleo/blob/main/docs/images/cerulean.png?raw=true"><br>
</div>

# CeRULEo
-----------------


# CeRULEo: Comprehensive utilitiEs for Remaining Useful Life Estimation methOds

[![Coverage Status](https://coveralls.io/repos/github/lucianolorenti/ceruleo/badge.svg?branch=main&service=github)](https://coveralls.io/github/lucianolorenti/ceruleo?branch=main)
[![Documentation](https://img.shields.io/badge/documentation-dev-brightgreen)](https://lucianolorenti.github.io/ceruleo/)
![pypi](https://img.shields.io/pypi/v/ceruleo)
![python-version](https://img.shields.io/badge/python-3.8%20%7C%203.9%20%7C%203.10-blue)
[![status](https://joss.theoj.org/papers/c879c234d7741885576ddc682416b41f/status.svg)](https://joss.theoj.org/papers/c879c234d7741885576ddc682416b41f)
## What is it?

**CeRULeo** is a Python package that provides a flexible environment designed to make working with predictive maintenance task both easy and intuitive. 


# Installation
It is recommended to use pip  for installation. Please make sure the latest version is installed:

```bash
pip install ceruleo            # normal install
pip install --upgrade ceruleo  # or update if needed
```

Alternatively, you could clone and install it from the sources:

```bash
git clone https://github.com/lucianolorenti/ceruleo.git
cd ceruleo
pip install .
```

# Contributing

We love your input! We want to make contributing to this project as easy and transparent as possible, whether it's:

* Reporting a bug
* Discussing the current state of the code
* Submitting a fix
* Proposing new features

Please feel free to open an [issue](https://github.com/lucianolorenti/ceruleo/issues/new/choose) if you have any questions, find any bugs, or have any ideas.  
Further information on how to contribute can be found by clicking  [here](https://github.com/lucianolorenti/ceruleo/blob/main/CONTRIBUTING.md).







Made with <3 @   <a href="https://www.dei.unipd.it/">  
         <img alt="University of Padova" src="https://github.com/lucianolorenti/ceruleo/blob/main/docs/images/unipd_logo.png?raw=true" width=100 />
      </a>

